@@ -13,9 +13,9 @@ public:
     void showImage(const QPixmap &pixmap);
     void showText(const QString &text);
     void showSvg(const QString &filepath);
-    void showGif(const QString &filepath);
+    void showAnimated(const QString &filepath);
 
-    bool trySetTransformationMode(Qt::TransformationMode mode);
+    bool trySetTransformationMode(Qt::TransformationMode mode, float scaleHint);
 
     QPixmap renderToPixmap();
 
