@@ -45,8 +45,9 @@ int main(int argc, char *argv[])
 
     if (!urlList.isEmpty()) {
         w.showUrls(urlList);
-        w.adjustWindowSizeBySceneRect();
     }
 
+    w.initWindowSize();
+
     return a.exec();
 }
