@@ -33,6 +33,7 @@ public:
     ~MainWindow() override;
 
     void showUrls(const QList<QUrl> &urls);
+    void initWindowSize();
     void adjustWindowSizeBySceneRect();
     QUrl currentImageFileUrl() const;
 
@@ -91,6 +92,7 @@ private slots:
     void on_actionSettings_triggered();
     void on_actionHelp_triggered();
     void on_actionProperties_triggered();
+    void on_actionLocateInFileManager_triggered();
     void on_actionQuitApp_triggered();
 
 private:
